summaryrefslogtreecommitdiff
path: root/lib/isc/include/isc/backtrace.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/isc/include/isc/backtrace.h')
-rw-r--r--lib/isc/include/isc/backtrace.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/isc/include/isc/backtrace.h b/lib/isc/include/isc/backtrace.h
index c0e98c0..7d7fc32 100644
--- a/lib/isc/include/isc/backtrace.h
+++ b/lib/isc/include/isc/backtrace.h
@@ -85,12 +85,12 @@ isc_backtrace_gettrace(void **addrs, int maxaddrs, int *nframes);
*/
isc_result_t
-isc_backtrace_getsymbolfromindex(int index, const void **addrp,
+isc_backtrace_getsymbolfromindex(int idx, const void **addrp,
const char **symbolp);
/*%<
* Returns the content of the internal symbol table of the given index.
* On success, *addrsp and *symbolp point to the address and the symbol of
* the 'index'th entry of the table, respectively. If 'index' is not in the
* range of the symbol table, ISC_R_RANGE will be returned.
*
* Requires
@@ -85,12 +85,12 @@ isc_backtrace_gettrace(void **addrs, int maxaddrs, int *nframes);
* Returns the content of the internal symbol table of the given index.
* On success, *addrsp and *symbolp point to the address and the symbol of
- * the 'index'th entry of the table, respectively. If 'index' is not in the
+ * the 'index'th entry of the table, respectively. If 'idx' is not in the
* range of the symbol table, ISC_R_RANGE will be returned.
*